@@ -17,8 +17,6 @@ class WhatIsThisCommand(object):
         else:
             print "{0}+file://{1}".format(repository.type, repository.working_directory)
 
-what_is_this_command = WhatIsThisCommand()
-
 class FetchCommand(object):
     def create_parser(self, subparser):
         subparser.add_argument("repository_uri", metavar="repository-uri")
@@ -32,8 +30,21 @@ class FetchCommand(object):
             print "fetch failed: {0}".format(error.message)
             exit(-1)
 
+class ArchiveCommand(object):
+    def create_parser(self, subparser):
+        subparser.add_argument("repository_uri", metavar="repository-uri")
+        subparser.add_argument("local_path", metavar="local-path")
+    
+    def execute(self, args):
+        try:
+            blah.fetcher.archive(args.repository_uri, args.local_path)
+        except (blah.errors.BlahUserError, blah.util.NoSuchCommandError) as error:
+            print "archive failed: {0}".format(error.message)
+            exit(-1)
+
+
 commands = {
-    "whatisthis": what_is_this_command,
-    "what-is-this": what_is_this_command,
-    "fetch": FetchCommand()
+    "what-is-this": WhatIsThisCommand(),
+    "fetch": FetchCommand(),
+    "archive": ArchiveCommand()
 }
